@@ -195,11 +195,12 @@ def set_idemailstatus_target_column(df):
     return df
 
 
-def set_bv_target_column(df):
+def set_bv_target_column(df,multiplier):
     if('BV' in df.columns):
         logger.info('Setting BV status target ')
         df = df[df.BV.notna()]
         df['BV']=df['BV'].astype('float32')
+        df['BV']=df['BV']*multiplier
         date_col = df['campaign_bulk_date']
         df.drop( labels=['campaign_bulk_date'], axis=1, inplace=True )
         df.insert(loc=0, value=date_col, column= 'campaign_bulk_date')
@@ -241,11 +242,11 @@ def set_bv_discrete_target_column(df,bins):
         raise Exception('No BV column found!!!!!')
     return df
 
-def set_target_column(df,model_type):
+def set_target_column(df,model_type,multiplier):
     if model_type == 'probability':
         df = set_idemailstatus_target_column( df=df )
     elif model_type == 'bv':
-        df = set_bv_target_column( df=df )
+        df = set_bv_target_column(df=df,multiplier=multiplier)
     elif model_type == 'bvfake':
         df = set_bv_fake_column( df=df )
     else:
@@ -332,7 +333,7 @@ def process_bulkstatus(df):
         df['is_New']=0
         df.loc[(df['BulkStatus'] == 0), 'is_New'] = 1        
         df['is_FU']=0
-        df.loc[(df['BulkStatus'] == 1), 'is_FU'] = 1        
+        df.loc[(df['BulkStatus'] == 2), 'is_FU'] = 1        
         df.drop(labels=['BulkStatus'],axis=1,inplace=True)
         logger.info('Deleted BulkStatus column')
         logger.info('OOO')
